@@ -39,8 +39,8 @@ ActionFlags = List[ActionFlag]
 class CommandParameters:
     command: CommandCls                                  #: The Command associated with this CommandParameters object
     formatter: CommandHelpFormatter                      #: The formatter used for this Command's help text
-    command_parent: Optional[CommandCls] = None          #: The parent Command, if any
-    parent: Optional[CommandParameters] = None           #: The parent Command's CommandParameters
+    command_parent: Optional[CommandCls]                 #: The parent Command, if any
+    parent: Optional[CommandParameters]                  #: The parent Command's CommandParameters
     action: Optional[Action] = None                      #: An Action Parameter, if specified
     _pass_thru: Optional[PassThru] = None                #: A PassThru Parameter, if specified
     sub_command: Optional[SubCommand] = None             #: A SubCommand Parameter, if specified
@@ -53,12 +53,16 @@ class CommandParameters:
     _deferred_positionals: List[BasePositional] = ()     #: Positional Parameters that are deferred to sub commands
     option_map: OptionMap                                #: Mapping of {--opt / -opt: Parameter}
 
-    def __init__(self, command: CommandCls, command_parent: Optional[CommandCls], config: CommandConfig):
+    def __init__(
+        self,
+        command: CommandCls,
+        command_parent: Optional[CommandCls],
+        parent_params: Optional[CommandParameters],
+        config: CommandConfig,
+    ):
         self.command = command
-        if command_parent is not None:
-            self.command_parent = command_parent
-            self.parent = command_parent.__class__.params(command_parent)
-
+        self.command_parent = command_parent
+        self.parent = parent_params
         self.config = config
         self._process_parameters()
 
@@ -106,10 +110,7 @@ class CommandParameters:
     def formatter(self) -> CommandHelpFormatter:
         from .formatting.commands import CommandHelpFormatter
 
-        if self.config is None:
-            formatter_factory = CommandHelpFormatter
-        else:
-            formatter_factory = self.config.command_formatter or CommandHelpFormatter
+        formatter_factory = self.config.command_formatter or CommandHelpFormatter
         formatter = formatter_factory(self.command, self)
         formatter.maybe_add_positionals(self.all_positionals)
         formatter.maybe_add_option(self._pass_thru)
@@ -117,31 +118,6 @@ class CommandParameters:
         formatter.maybe_add_groups(self.groups)
         return formatter
 
-    @cached_property
-    def _classified_combo_options(self) -> Tuple[Dict[str, BaseOption], Dict[str, BaseOption]]:
-        multi_char_combos = {}
-        single_char_combos = {}
-        for combo, param in self.combo_option_map.items():
-            if len(combo) == 1:
-                single_char_combos[combo] = param
-            else:
-                multi_char_combos[combo] = param
-        return single_char_combos, multi_char_combos
-
-    @cached_property
-    def _potentially_ambiguous_combo_options(self) -> Dict[str, Tuple[BaseOption, Dict[str, BaseOption]]]:
-        single_char_combos, multi_char_combos = self._classified_combo_options
-        if not multi_char_combos:
-            return {}
-
-        ambiguous_combo_options = {}
-        for combo, param in multi_char_combos.items():
-            singles = {c: single_char_combos[c] for c in combo if c in single_char_combos}
-            if singles:
-                ambiguous_combo_options[combo] = (param, singles)
-
-        return ambiguous_combo_options
-
     @property
     def _has_help(self) -> bool:
         return help_action in self.always_available_action_flags or (self.parent and self.parent._has_help)
@@ -196,7 +172,7 @@ class CommandParameters:
             if param.group:
                 _find_groups(groups, param)
 
-        if self.config and self.config.add_help and (not self.parent or not self.parent._has_help):
+        if self.config.add_help and self.command_parent is not None and (not self.parent or not self.parent._has_help):
             options.append(help_action)
 
         self._process_positionals(positionals)
@@ -273,19 +249,9 @@ class CommandParameters:
         self._process_action_flags(options)
         self.combo_option_map = dict(sorted(combo_option_map.items(), key=lambda kv: (-len(kv[0]), kv[0])))  # noqa
 
-        if self.config and self.config.ambiguous_short_combos == AmbiguousComboMode.STRICT:
+        if self.config.ambiguous_short_combos == AmbiguousComboMode.STRICT:
             self._strict_ambiguous_short_combo_check()
 
-    def _strict_ambiguous_short_combo_check(self):
-        potentially_ambiguous_combo_options = self._potentially_ambiguous_combo_options
-        if not potentially_ambiguous_combo_options:
-            return
-
-        param_conflicts_map = {
-            param: singles.values() for param, singles in potentially_ambiguous_combo_options.values()
-        }
-        raise AmbiguousShortForm(param_conflicts_map)
-
     def _process_option_strs(
         self, param: BaseOption, opt_type: str, opt_strs: List[str], option_map: OptionMap, combo_option_map: OptionMap
     ):
@@ -340,8 +306,85 @@ class CommandParameters:
 
     # endregion
 
+    # region Ambiguous Short Combo Handling
+
+    def _strict_ambiguous_short_combo_check(self):
+        # Called during initial Option processing when using AmbiguousComboMode.STRICT
+        potentially_ambiguous_combo_options = self._potentially_ambiguous_combo_options
+        if not potentially_ambiguous_combo_options:
+            return
+
+        param_conflicts_map = {
+            param: singles.values() for param, singles in potentially_ambiguous_combo_options.values()
+        }
+        raise AmbiguousShortForm(param_conflicts_map)
+
+    @cached_property
+    def _classified_combo_options(self) -> Tuple[OptionMap, OptionMap]:
+        multi_char_combos = {}
+        single_char_combos = {}
+        for combo, param in self.combo_option_map.items():
+            if len(combo) == 1:
+                single_char_combos[combo] = param
+            else:
+                multi_char_combos[combo] = param
+        return single_char_combos, multi_char_combos
+
+    @cached_property
+    def _potentially_ambiguous_combo_options(self) -> Dict[str, Tuple[BaseOption, OptionMap]]:
+        single_char_combos, multi_char_combos = self._classified_combo_options
+        if not multi_char_combos:
+            return {}
+        return _find_ambiguous_combos(single_char_combos, multi_char_combos)
+
+    @cached_property
+    def _nested_potentially_ambiguous_combo_options(self):
+        single_char_combos, multi_char_combos = self._classified_combo_options
+        for params in self._iter_nested_params():
+            nested_single_char_combos, nested_multi_char_combos = params._classified_combo_options
+            single_char_combos.update(nested_single_char_combos)
+            multi_char_combos.update(nested_multi_char_combos)
+
+        if not multi_char_combos:
+            return {}
+        return _find_ambiguous_combos(single_char_combos, multi_char_combos)
+
+    def _is_combo_potentially_ambiguous(self, option: str) -> Optional[bool]:
+        # Called by short_option_to_param_value_pairs after ensuring the length is > 1
+        to_check = option[1:]  # Strip leading '-'
+        # Note: len(to_check) will never be 2 here - this is only called if len(option) > 2
+        potentially_ambiguous_combo_options = self._nested_potentially_ambiguous_combo_options
+        acm = self.config.ambiguous_short_combos
+        if acm == AmbiguousComboMode.PERMISSIVE and to_check in potentially_ambiguous_combo_options:
+            return True  # Permissive mode allows exact matches of multi-char short forms
+        elif acm == AmbiguousComboMode.IGNORE:
+            return None
+
+        ambiguous = set()
+        for multi, (param, singles) in potentially_ambiguous_combo_options.items():
+            if multi in to_check:
+                ambiguous.add(param)
+                ambiguous.update(p for c, p in singles.items() if c in to_check)
+
+        if ambiguous:
+            raise AmbiguousCombo(ambiguous, option)
+
+        return False
+
+    # endregion
+
     # region Option Processing
 
+    def _iter_nested_params(self) -> Iterator[CommandParameters]:
+        if not self.sub_command:
+            return
+        for choice in self.sub_command.choices.values():
+            command = choice.target
+            try:
+                yield command.__class__.params(command)
+            except AttributeError:  # The target was None (it's a subcommand's local choice)
+                pass
+
     def get_option_param_value_pairs(self, option: str) -> Optional[Tuple[BaseOption, ...]]:
         if option.startswith('---'):
             return None
@@ -377,14 +420,15 @@ class CommandParameters:
             option, value = option.split('=', 1)
         except ValueError:
             value = None
-
-        if len(option) > 2:  # 2 due to '-' prefix
-            self._ensure_combo_is_unambiguous(option)
+        else:
+            # Note: if the option is not in this Command's option_map, the KeyError is handled by CommandParser
+            return [(option, self.option_map[option], value)]
 
         try:
             param = self.option_map[option]
         except KeyError:
-            if value is not None:
+            opt_len = len(option)
+            if opt_len < 2 or (opt_len > 2 and self._is_combo_potentially_ambiguous(option)):
                 raise
         else:
             return [(option, param, value)]
@@ -396,28 +440,9 @@ class CommandParameters:
         if param.would_accept(value, short_combo=True):
             return [(key, param, value)]
         else:
+            # Multi-char short options can never be combined with each other, but single-char ones can
             return [(c, combo_option_map[c], None) for c in option[1:]]
 
-    def _ensure_combo_is_unambiguous(self, option: str):
-        # Called by short_option_to_param_value_pairs after ensuring the length is > 1
-        acm = AmbiguousComboMode.PERMISSIVE if not self.config else self.config.ambiguous_short_combos
-        if acm == AmbiguousComboMode.IGNORE:
-            return
-
-        to_check = option[1:]  # Strip leading '-'
-        potentially_ambiguous_combo_options = self._potentially_ambiguous_combo_options
-        if acm == AmbiguousComboMode.PERMISSIVE and to_check in potentially_ambiguous_combo_options:
-            return  # Permissive mode allows exact matches of multi-char short forms
-
-        ambiguous = set()
-        for multi, (param, singles) in potentially_ambiguous_combo_options.items():
-            if multi in to_check:
-                ambiguous.add(param)
-                ambiguous.update(p for c, p in singles.items() if c in to_check)
-
-        if ambiguous:
-            raise AmbiguousCombo(ambiguous, option)
-
     def find_option_that_accepts_values(self, option: str) -> Optional[BaseOption]:
         if option.startswith('--'):
             param = self.long_option_to_param_value_pair(option)[1]
@@ -432,15 +457,7 @@ class CommandParameters:
         return None
 
     def find_nested_option_that_accepts_values(self, option: str) -> Optional[BaseOption]:
-        if not self.sub_command:
-            return None
-
-        for choice in self.sub_command.choices.values():
-            command = choice.target
-            try:
-                params = command.__class__.params(command)
-            except AttributeError:  # The target was None (it's a subcommand's local choice)
-                continue
+        for params in self._iter_nested_params():
             try:
                 param = params.find_option_that_accepts_values(option)
             except KeyError:
@@ -456,12 +473,7 @@ class CommandParameters:
         return None
 
     def find_nested_pass_thru(self) -> Optional[PassThru]:
-        if not self.sub_command:
-            return None
-
-        for choice in self.sub_command.choices.values():
-            command = choice.target
-            params = command.__class__.params(command)
+        for params in self._iter_nested_params():
             if params._pass_thru:
                 return params._pass_thru
 
@@ -506,3 +518,15 @@ def _find_groups(groups: Set[ParamGroup], param: ParamBase):
     while group:
         groups.add(group)
         group = group.group
+
+
+def _find_ambiguous_combos(
+    single_char_combos: OptionMap, multi_char_combos: OptionMap
+) -> Dict[str, Tuple[BaseOption, OptionMap]]:
+    ambiguous_combo_options = {}
+    for combo, param in multi_char_combos.items():
+        singles = {c: single_char_combos[c] for c in combo if c in single_char_combos}
+        if singles:
+            ambiguous_combo_options[combo] = (param, singles)
+
+    return ambiguous_combo_options
