@@ -405,7 +405,6 @@ class PassThruHelpFormatter(ParamHelpFormatter, param_cls=PassThru):
 
 class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa  # pylint: disable=W0223
     required_formatter_map: BoolFormatterMap = {True: '{{{}}}'.format, False: '[{}]'.format}
-    # TODO: #18 Group order changes between invocations - should be sorted as declared or alphanumerically (config?)
 
     def _get_choice_delim(self) -> str:
         param: ParamGroup = self.param
@@ -425,16 +424,16 @@ class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa  # p
         if description:
             return description
         group = self.param
-        if not group.description and not group._name:
-            if ctx.config.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
-                return 'Mutually {} options'.format('exclusive' if group.mutually_exclusive else 'dependent')
-            else:
-                return 'Optional arguments'
-        else:
+        if group.description or group._name:
             description = group.description or f'{group.name} options'
             if ctx.config.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
-                description += ' (mutually {})'.format('exclusive' if group.mutually_exclusive else 'dependent')
+                description += f' (mutually {"exclusive" if group.mutually_exclusive else "dependent"})'
             return description
+        elif ctx.config.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
+            return f'Mutually {"exclusive" if group.mutually_exclusive else "dependent"} options'
+
+        adjective = 'Required' if group.required else 'Other' if group.contains_required else 'Optional'
+        return f'{adjective} arguments'
 
     def _get_spacer(self) -> str:
         group = self.param
